==> slint-ui-0.3.2.tgz: package/LICENSES/LicenseRef-Slint-commercial.md <==
# Slint Software License Agreement

Version 1.2

Copyright © 2022 SixtyFPS GmbH <https://slint-ui.com/imprint.html>

SixtyFPS GmbH with offices at Oranienburger Str. 44, 16540 Hohen Neuendorf,
Germany (**SixtyFPS**, **us**, **we** or **our**) grants a license to the
software (**Licensed Software**), as specified herein, subject to the Terms and
Conditions of this Slint Software License Agreement (**Agreement**).

By using the Licensed Software, **you** agree to be bound by this Agreement.
**If you do not agree, do not use the Licensed Software.** If you are accessing
and using the Licensed Software on behalf of a company (such as your employer)
or other legal entity, you represent and warrant that you have the authority to
bind that company or other legal entity to this Agreement. In that case, **you**
and **your** will refer to that company or other legal entity.

Each Party to this Agreement may be referred to herein individually as a
**Party** or collectively as the **Parties**.

## Licensed Software

The Licensed Software includes

1. Slint compiler tool to translate Slint Design Markup Language files to Rust
    (last stable Rust version at the time of licensed Slint version) and C++
    (second last C++ version at the time of licensed Slint version),

2. Slint run-time library that can render interactive user-interfaces and
    provides Rust and C++ APIs (as per above versioning) to control the
    interfaces,

3. API Documentation for Slint and reference documentation for Slint Design
    Markup Language, and

4. Source code of Slint.

## Terms and Conditions

1. The Licensed Software is protected by copyright laws and international
    copyright treaties, as well as other intellectual property laws and
    treaties. The Licensed Software is licensed, not sold.

2. The Licensed Software may provide links to third Party libraries or code
    (collectively **Third Party Libraries**) to implement various functions.
    Third Party Libraries do not comprise part of the Licensed Software. In some
    cases, access to Third Party Libraries may be included along with the
    Licensed Software delivery as a convenience for development and testing
    only. You acknowledge:

    1. that some Third-Party Libraries may require additional licensing of
        copyright and/or patents from the owners of such, and

    2. that distribution of any of the Licensed Software referencing any portion
        of a Third-Party Library may require appropriate licensing from such
        third parties. All such Third Party Libraries, along with applicable
        copyright notices and licenses, will be listed and made available to
        you.

3. As part of the license grant, a Slint Software License Certificate
    (**License Certificate**) will be issued containing details of

    1. the license grant,

    2. the permitted scope of your use of the Licensed Software, and

    3. your contact details.

    In case of any changes or deviations to the information noted in the License
    Certificate, you are obliged to notify us in writing, not later than 7 days
    after any such change or deviation has occured.

4. The Term of this Agreement shall begin on the date mentioned in the License
    Certificate (**Effective Date**) and shall continue unless terminated
    earlier as herein provided (**Term**).

5. New releases of the Licensed Software (**Updates**) will be made available
    to you for the period (**Maintenance Period**) specified in the License
    Certificate. Such Updates may be bound by additional license terms. You
    consent to any such additional license terms, without which you may not
    install, copy, or otherwise use such Updates.

6. The Licensed Software is to be used exclusively with your software
    products (**Products**) specified in the License Certificate.

7. We grant you a perpetual, non-exclusive, non-transferable right to use the
    Licensed Software, including making modifications, for the sole purposes of
    designing, developing, and testing your Products during the Term. The number
    of **Users** using the Licensed Software to design, develop and test your
    Products is limited to the amount of **User Seats** specified in the License
    Certificate. For clarity, each unique User is counted as one User Seat.

8. We grant you a perpetual, non-exclusive, non-transferable right to reproduce
    and distribute the object code form of the Licensed Software, including any
    modifications made to the Licensed Software, during the Term. Such
    distributions is permitted only with your Products and limited to the amount
    of **Distributions** specified in the License Certificate.

9. The license grants are conditional on the full and timely payment of all
    applicable **Fees**; if said Fees are not paid in full and by their due
    date, the license shall not be granted and your Products shall be deemed as
    made in breach of the Agreement ex tunc.

10. Clause 9 above shall not apply if the license has been granted to you under
    the **Ambassador** program. Instead, the license grants shall be conditional
    on the fullfilment of the obligations as specified herein. If said
    obligations are not fulfilled, the license shall not be granted and your
    Products shall be deemed as made in breach of the Agreement ex tunc. The
    obligations are as follows:

    1. Showcase: You grant us the right to use your name, logo and your
        Products in our marketing materials,

    2. Spread the word: You will include reasonably visible notices in the
        documentation, marketing materials and social media channels related to
        your Products that such were built with the Licensed Software,

    3. Give feedback: You agree to provide relevant feedback that would
        help us improve the Licensed Software. We may use any such
        feedback in testimonials.

11. The Fees and any other charges under this Agreement shall be paid by
    you no later than thirty (30) days from the date of the applicable
    invoice from us. A late payment charge of the lower of (a) one percent
    per month; or (b) the interest rate stipulated by applicable law, shall be
    charged on any unpaid balances that remain past due and which have not been
    disputed by you in good faith.

12. The Fees and any other charges payable under this Agreement are gross
    amounts but exclusive of any value added tax, use tax, sales tax,
    withholding tax and other taxes, duties or tariffs levied directly for the
    sale, delivery or use of the Licensed Software pursuant to any applicable
    law.

13. The Parties also agree to all of the following conditions:

    1. You may not remove or alter any copyright, trademark or other
        proprietary rights notice contained in any portion of the Licensed
        Software,

    2. Your Products may not compete with the Licensed Software,

    3. You will indemnify and hold us, our affiliated companies and our
        suppliers, harmless from and against any claims or liabilities
        arising out of the use, reproduction or distribution of your
        Products, except as set out in clause 13.4. immediately below,

    4. We shall indemnify and hold you harmless from and against any
        claims from third parties alleging that the use of the Licensed Software
        as set out in this Agreement infringes or will infringe such third
        parties intellectual property rights or other rights,

    5. A Party shall promptly notify the other Party if it receives a claim that
        the other Party shall or may be obliged to indemnify. The Parties shall
        promptly give each other information and other assistance needed for
        handling the claim. The Indemnifying Party may, at its cost and in its
        sole discretion, take control of the defense of such claim, including
        the conduct of any litigation or arbitration and the negotiation of any
        settlement, in which case the indemnifying Party shall not compromise or
        settle or otherwise dispose of the claim, in whole or in part, where
        such compromise or settlement or disposal would require any admission or
        stipulation which would reasonably be expected to have an adverse effect
        on the commercial reputation of the indemnified Party, without the prior
        written consent of the indemnified Party. Where the indemnifying Party
        has not taken control of the defense of the claim, the indemnified Party
        shall not compromise or settle or fail adequately to defend or otherwise
        dispose of a claim, in whole or in part, without the written consent of
        the indemnifying Party, such consent not to be unreasonably withheld or
        delayed.

14. The Licensed Software is licensed to you "as is". To the maximum extent
    permitted by applicable law, we on behalf of us and our suppliers,
    disclaim all warranties and conditions, either express or implied,
    including, but not limited to, any implied warranties of merchantability or
    fitness for a particular purpose, title and non-infringement with regard to
    the Licensed Software. The warranty disclaimer in the foregoing
    notwithstanding, you may have specific legal rights which may vary from
    state/jurisdiction to state/jurisdiction; as far as legally permissible, you
    waive any such legal rights vis-à-vis us.

15. We shall not under any circumstances be liable to you based on failure of
    the Licensed Software if the failure resulted from your changing of the
    Licensed Software, from your accident, abuse or misapplication, nor shall
    we except in case of gross negligence or willful misconduct be
    liable for special damages, punitive or exemplary damages, damages for loss
    of profits or interruption of business or for loss or corruption of data,
    nor shall any award of damages exceed the total amount you paid to us in
    connection with this Agreement.

16. Each Party shall hold Confidential Information of the other Party, its
    customers, and licensors in confidence, and without written permission from
    will not disclose to any person or use for its own benefit, any such
    information. **Confidential Information** includes without limitation the
    terms of this Agreement, computer software programs developed or licensed by
    the Parties, including all documentation and methods or concepts utilized
    therein, all adaptations and modifications thereto and derivative works
    thereof, and related materials and information. Confidential Information
    also includes any other information identified by either Party, its
    licensors, or customers as proprietary or confidential, or which would
    reasonably be understood under the circumstances to be confidential. All
    Confidential Information shall remain the sole property of each respective
    Party. Information will not be considered to be Confidential Information if

    1. available to the public other than by a breach of this Agreement;

    2. rightfully received from a third Party not in breach of any obligation of
        confidentiality;

    3. independently developed by a Party without access to Confidential
        Information of the other Party;

    4. known to the other Party at the time of disclosure;

    5. produced in compliance with applicable law or a court order, provided the
        other Party is given notice and opportunity to intervene; or

    6. it does not constitute a trade secret and more than five (5) years have
        elapsed from the date of disclosure. In addition to any other rights or
        remedies available, each Party shall be entitled to enforcement of such
        obligations by court injunction.

17. During the Term, an independent, certified auditor on our behalf, may, upon
    its reasonable request, with 30 (thirty) days written notice, and at its
    sole expense, examine your books and records solely with respect to your use
    of the Licensed Software. Any such audit shall be conducted during regular
    business hours at your facilities and shall not unreasonably interfere with
    your business activities. Our auditor shall not remove, copy, or
    redistribute any electronic material during the course of an audit. If an
    audit reveals that you are using the Licensed Software in a way that is in
    material violation of the terms of this Agreement, then you shall pay us
    reasonable costs of conducting the audit. Our auditor shall only be allowed
    to report violations of the terms of this Agreement, with a copy to you. You
    shall be provided the right to provide comments to the report before it is
    finalized.

18. If you materially breach this Agreement, we will provide a 60 (sixty) days
    written notice to you during which any such breach(es) may be cured, failing
    which we will terminate the agreement. You undertake to pay a contractual
    penalty for each case of negligent breach of this Agreement of EUR 10000
    (ten thousand euros), which shall not be subject to a judicial right of
    reduction. We shall in any case be free to assert any further damage/loss or
    other claims. The amount of contractual penalty shall be offset against
    claims for damages, if any.

19. You may terminate this Agreement at any time for any reason upon 90 (ninety)
    days notice to us and upon payment of all applicable fees and contractual
    penalties, if any, in connection with the use of the Licensed Software.

20. Both Parties shall comply with all applicable laws and regulations relating
    to the Licensed Software in the countries in which the Parties use or modify
    the Licensed Software.

21. All notices and communications between the Parties shall be in writing and
    shall be deemed given when received. For avoidance of doubt, email is
    considered a written form of communication.

22. This Agreement shall be construed, interpreted and governed by the laws of
    the Federal Republic of Germany.

23. No term or condition contained in your purchase order will apply unless
    expressly accepted by us in writing.

24. You may assign this Agreement, in whole or in part (whether by operation of
    law or otherwise), with prior consent from us, which shall not be
    unreasonably withheld or delayed. We may assign this Agreement or any of its
    rights hereunder or delegate any of its obligations hereunder with prior
    notice to you. Any attempt to assign this Agreement other than in accordance
    with this provision shall be null and void.

25. This Agreement constitutes the complete agreement between the Parties and
    supersedes all prior or contemporaneous discussions, representations, and
    proposals, written or oral, with respect to the subject matters discussed
    herein. No modification of this Agreement will be effective unless contained
    in a written document executed by an authorized representative of each
    Party. If any provision of the Agreement is found void or unenforceable, the
    remainder will remain valid and enforceable according to its terms. If any
    remedy provided is determined to have failed for its essential purpose, all
    limitations of liability and exclusions of damages set forth in this
    Agreement shall remain in effect.

==> slint-ui-1.0.0.tgz: package/LICENSES/LicenseRef-Slint-commercial.md <==
# Slint Software License Agreement

Version 1.2

Copyright © 2022 SixtyFPS GmbH <https://slint-ui.com/imprint.html>

SixtyFPS GmbH with offices at Oranienburger Str. 44, 16540 Hohen Neuendorf,
Germany (**SixtyFPS**, **us**, **we** or **our**) grants a license to the
software (**Licensed Software**), as specified herein, subject to the Terms and
Conditions of this Slint Software License Agreement (**Agreement**).

By using the Licensed Software, **you** agree to be bound by this Agreement.
**If you do not agree, do not use the Licensed Software.** If you are accessing
and using the Licensed Software on behalf of a company (such as your employer)
or other legal entity, you represent and warrant that you have the authority to
bind that company or other legal entity to this Agreement. In that case, **you**
and **your** will refer to that company or other legal entity.

Each Party to this Agreement may be referred to herein individually as a
**Party** or collectively as the **Parties**.

## Licensed Software

The Licensed Software includes

1. Slint compiler tool to translate Slint Design Markup Language files to Rust
    (last stable Rust version at the time of licensed Slint version) and C++
    (second last C++ version at the time of licensed Slint version),

2. Slint run-time library that can render interactive user-interfaces and
    provides Rust and C++ APIs (as per above versioning) to control the
    interfaces,

3. API Documentation for Slint and reference documentation for Slint Design
    Markup Language, and

4. Source code of Slint.

## Terms and Conditions

1. The Licensed Software is protected by copyright laws and international
    copyright treaties, as well as other intellectual property laws and
    treaties. The Licensed Software is licensed, not sold.

2. The Licensed Software may provide links to third Party libraries or code
    (collectively **Third-Party Libraries**) to implement various functions.
    Third-Party Libraries do not comprise part of the Licensed Software. In some
    cases, access to Third-Party Libraries may be included along with the
    Licensed Software delivery as a convenience for development and testing
    only. You acknowledge:

    1. that some Third-Party Libraries may require additional licensing of
        copyright and/or patents from the owners of such, and

    2. that distribution of any of the Licensed Software referencing any portion
        of a Third-Party Library may require appropriate licensing from such
        third parties. All such Third-Party Libraries, along with applicable
        copyright notices and licenses, will be listed and made available to
        you.

3. As part of the license grant, a Slint Software License Certificate
    (**License Certificate**) will be issued containing details of

    1. the license grant,

    2. the permitted scope of your use of the Licensed Software, and

    3. your contact details.

4. In case of any changes or deviations to the information noted in the License
    Certificate, you are obliged to notify us in writing, not later than 7 days
    after any such change or deviation has occurred.

5. The Term of this Agreement shall begin on the date mentioned in the License
    Certificate (**Effective Date**) and shall continue unless terminated
    earlier as herein provided (**Term**).

6. New releases of the Licensed Software (**Updates**) will be made available
    to you for the period (**Maintenance Period**) specified in the License
    Certificate. Such Updates may be bound by additional license terms. You
    consent to any such additional license terms, without which you may not
    install, copy, or otherwise use such Updates.

7. The Licensed Software is to be used exclusively with your software
    products (**Products**) specified in the License Certificate.

8. We grant you a perpetual, non-exclusive, non-transferable right to use the
    Licensed Software, including making modifications, for the sole purposes of
    designing, developing, and testing your Products during the Term. The number
    of **Users** using the Licensed Software to design, develop, and test your
    Products is limited to the amount of **User Seats** specified in the License
    Certificate. For clarity, each unique User is counted as one User Seat.

9. We grant you a perpetual, non-exclusive, non-transferable right to reproduce
    and distribute the object code form of the Licensed Software, including any
    modifications made to the Licensed Software, during the Term. Such
    distributions are permitted only with your Products and limited to the number
    of **Distributions** specified in the License Certificate.

10. The license grants are conditional on the full and timely payment of all
    applicable **Fees**; if said Fees are not paid in full and by their due
    date, the license shall not be granted and your Products shall be deemed as
    made in breach of the Agreement ex tunc.

11. Clause 10 above shall not apply if the license has been granted to you under
    the **Ambassador** program. Instead, the license grants shall be conditional
    on the fulfillment of the obligations as specified herein. If said
    obligations are not fulfilled, the license shall not be granted and your
    Products shall be deemed as made in breach of the Agreement ex tunc. The
    obligations are as follows:

    1. Showcase: You grant us the right to use your name, logo, and your
        Products in our marketing materials,

    2. Spread the word: You will include visible notices in the documentation,
        marketing materials, and social media channels related to your Products
        that such were built with the Licensed Software,

    3. Give feedback: You agree to provide feedback that would help us improve
        the Licensed Software. We may use any such feedback in testimonials.

12. The Fees and any other charges under this Agreement shall be paid by
    you no later than thirty (30) days from the date of the applicable
    invoice from us. A late payment charge of five percent per month over and
    above the interest rate stipulated by applicable law shall be charged on any
    unpaid balances that remain past due and which have not been disputed by you
    in good faith.

13. The Fees and any other charges payable under this Agreement are gross
    amounts but exclusive of any value added tax, use tax, sales tax,
    withholding tax and other taxes, duties or tariffs levied directly for the
    sale, delivery, or use of the Licensed Software pursuant to any applicable
    law.

14. The Parties also agree to all the following conditions:

    1. You may not remove or alter any copyright, trademark, or other
        proprietary rights notice contained in any portion of the Licensed
        Software,

    2. Your Products may not compete with the Licensed Software,

    3. You will indemnify and hold us, our affiliated companies, and our
        suppliers, harmless from and against any claims or liabilities
        arising out of the use, reproduction, or distribution of your
        Products, except as set out in clause 14.4. immediately below,

    4. We shall indemnify and hold you harmless from and against any
        claims from third parties alleging that the use of the Licensed Software
        as set out in this Agreement infringes or will infringe such third
        parties' intellectual property rights or other rights,

    5. A Party shall promptly notify the other Party if it receives a claim that
        the other Party shall or may be obliged to indemnify. The Parties shall
        promptly give each other information and other assistance needed for
        handling the claim. The Indemnifying Party may, at its cost and in its
        sole discretion, take control of the defense of such claim, including
        the conduct of any litigation or arbitration and the negotiation of any
        settlement, in which case the indemnifying Party shall not compromise or
        settle or otherwise dispose of the claim, in whole or in part, where
        such compromise or settlement or disposal would require any admission or
        stipulation which would reasonably be expected to have an adverse effect
        on the commercial reputation of the indemnified Party, without the prior
        written consent of the indemnified Party. Where the indemnifying Party
        has not taken control of the defense of the claim, the indemnified Party
        shall not compromise or settle or fail adequately to defend or otherwise
        dispose of a claim, in whole or in part, without the written consent of
        the indemnifying Party, such consent not to be unreasonably withheld or
        delayed.

15. The Licensed Software is licensed to you "as is". To the maximum extent
    permitted by applicable law, we on behalf of us and our suppliers,
    disclaim all warranties and conditions, either express or implied,
    including, but not limited to, any implied warranties of merchantability or
    fitness for a particular purpose, title, and non-infringement with regard to
    the Licensed Software. The warranty disclaimer in the foregoing
    notwithstanding, you may have specific legal rights which may vary from
    state/jurisdiction to state/jurisdiction; as far as legally permissible, you
    waive any such legal rights vis-à-vis us.

16. We shall not under any circumstances be liable to you based on failure of
    the Licensed Software if the failure resulted from your changing of the
    Licensed Software, from your accident, abuse or misapplication, nor shall
    we except in case of gross negligence or willful misconduct be
    liable for special damages, punitive or exemplary damages, damages for loss
    of profits or interruption of business or for loss or corruption of data,
    nor shall any award of damages exceed the total amount you paid to us in
    connection with this Agreement.

17. Each Party shall hold Confidential Information of the other Party, its
    customers, and licensors in confidence, and without written permission from
    will not disclose to any person or use for its own benefit, any such
    information. **Confidential Information** includes without limitation the
    terms of this Agreement, computer software programs developed or licensed by
    the Parties, including all documentation and methods or concepts utilized
    therein, all adaptations and modifications thereto and derivative works
    thereof, and related materials and information. Confidential Information
    also includes any other information identified by either Party, its
    licensors, or customers as proprietary or confidential, or which would
    reasonably be understood under the circumstances to be confidential. All
    Confidential Information shall remain the sole property of each respective
    Party. Information will not be considered as Confidential Information if

    1. available to the public other than by a breach of this Agreement;

    2. rightfully received from a third Party not in breach of any obligation of
        confidentiality;

    3. independently developed by a Party without access to Confidential
        Information of the other Party;

    4. known to the other Party at the time of disclosure;

    5. produced in compliance with applicable law or a court order, provided the
        other Party is given notice and opportunity to intervene; or

    6. it does not constitute a trade secret and more than five (5) years have
        elapsed from the date of disclosure. In addition to any other rights or
        remedies available, each Party shall be entitled to enforcement of such
        obligations by court injunction.

18. During the Term, an independent, certified auditor on our behalf, may, upon
    its reasonable request, with 30 (thirty) days written notice, and at its
    sole expense, examine your books and records solely with respect to your use
    of the Licensed Software. Any such audit shall be conducted during regular
    business hours at your facilities and shall not unreasonably interfere with
    your business activities. Our auditor shall not remove, copy, or
    redistribute any electronic material during an audit. If an audit reveals that
    you are using the Licensed Software in a way that is in material violation
    of the terms of this Agreement, then you shall pay us reasonable costs of
    conducting the audit. Our auditor shall only be allowed to report violations
    of the terms of this Agreement, with a copy to you. You shall be provided
    the right to provide comments to the report before it is finalized.

19. If you materially breach this Agreement, we will provide a 60 (sixty) days
    written notice to you during which any such breach(es) may be cured, failing
    which we will terminate the agreement. You undertake to pay a contractual
    penalty for each case of negligent breach of this Agreement of EUR 10000
    (ten thousand euros), which shall not be subject to a judicial right of
    reduction. We shall in any case be free to assert any further damage/loss or
    other claims. The amount of contractual penalty shall be offset against
    claims for damages, if any.

20. You may terminate this Agreement at any time for any reason upon 90 (ninety)
    days notice to us and upon payment of all applicable fees and contractual
    penalties, if any, in connection with the use of the Licensed Software.

21. Both Parties shall comply with all applicable laws and regulations relating
    to the Licensed Software in the countries in which the Parties use or modify
    the Licensed Software.

22. All notices and communications between the Parties shall be in writing and
    shall be deemed given when received. For avoidance of doubt, email is
    considered a written form of communication.

23. This Agreement shall be construed, interpreted, and governed by the laws of
    the Federal Republic of Germany.

24. No term or condition contained in your purchase order will apply unless
    expressly accepted by us in writing.

25. You may assign this Agreement, in whole or in part (whether by operation of
    law or otherwise), with prior consent from us, which shall not be
    unreasonably withheld or delayed. We may assign this Agreement or any of its
    rights hereunder or delegate any of its obligations hereunder with prior
    notice to you. Any attempt to assign this Agreement other than in accordance
    with this provision shall be null and void.

26. This Agreement constitutes the complete agreement between the Parties and
    supersedes all prior or contemporaneous discussions, representations, and
    proposals, written or oral, with respect to the subject matters discussed
    herein. No modification of this Agreement will be effective unless contained
    in a written document executed by an authorized representative of each
    Party. If any provision of the Agreement is found void or unenforceable, the
    remainder will remain valid and enforceable according to its terms. If any
    remedy provided is determined to have failed for its essential purpose, all
    limitations of liability and exclusions of damages set forth in this
    Agreement shall remain in effect.
